@@ -10,8 +10,6 @@
     :license: BSDL.
 """
 
-from __future__ import absolute_import
-
 import os
 import re
 import posixpath
@@ -20,18 +18,20 @@ import pkg_resources
 from collections import namedtuple
 from docutils import nodes
 from sphinx import addnodes
+from sphinx.util import logging
 from sphinx.util.osutil import ensuredir
 
 import blockdiag.utils.rst.nodes
 import blockdiag.utils.rst.directives
 from blockdiag.utils.bootstrap import detectfont, Application
-from blockdiag.utils.compat import u, string_types
 from blockdiag.utils.fontmap import FontMap
 from blockdiag.utils.rst.directives import with_blockdiag
 
 # fontconfig; it will be initialized on `builder-inited` event.
 fontmap = None
 
+logger = logging.getLogger(__name__)
+
 
 class blockdiag_node(blockdiag.utils.rst.nodes.blockdiag):
     def to_drawer(self, image_format, builder, **kwargs):
@@ -56,11 +56,7 @@ class blockdiag_node(blockdiag.utils.rst.nodes.blockdiag):
                        fontmap=builder.config.blockdiag_fontmap,
                        format=image_format,
                        transparency=builder.config.blockdiag_transparency)
-        if hasattr(builder, 'imgpath'):  # Sphinx (<= 1.2.x) or HTML writer
-            outputdir = builder.imgpath
-        else:
-            outputdir = ''
-        return posixpath.join(outputdir, self.get_path(**options))
+        return posixpath.join(builder.imgpath, self.get_path(**options))
 
     def get_abspath(self, image_format, builder):
         options = dict(antialias=builder.config.blockdiag_antialias,
@@ -69,13 +65,7 @@ class blockdiag_node(blockdiag.utils.rst.nodes.blockdiag):
                        format=image_format,
                        transparency=builder.config.blockdiag_transparency)
 
-        if hasattr(builder, 'imagedir'):  # Sphinx (>= 1.3.x)
-            outputdir = os.path.join(builder.outdir, builder.imagedir)
-        elif hasattr(builder, 'imgpath'):  # Sphinx (<= 1.2.x) and HTML writer
-            outputdir = os.path.join(builder.outdir, '_images')
-        else:
-            outputdir = builder.outdir
-        path = os.path.join(outputdir, self.get_path(**options))
+        path = os.path.join(builder.outdir, builder.imagedir, self.get_path(**options))
         ensuredir(os.path.dirname(path))
 
         return path
@@ -92,7 +82,7 @@ def resolve_reference(builder, href):
     if href is None:
         return None
 
-    pattern = re.compile(u("^:ref:`(.+?)`"), re.UNICODE)
+    pattern = re.compile("^:ref:`(.+?)`", re.UNICODE)
     matched = pattern.search(href)
     if matched is None:
         return href
@@ -110,7 +100,7 @@ def resolve_reference(builder, href):
             else:
                 return xref['refuri']
         else:
-            builder.warn('undefined label: %s' % refid)
+            logger.warning('undefined label: %s', refid)
             return None
 
 
@@ -118,13 +108,10 @@ def html_render_svg(self, node):
     image = node.to_drawer('SVG', self.builder, filename=None, nodoctype=True)
     image.draw()
 
-    if 'align' in node['options']:
-        align = node['options']['align']
-        self.body.append('<div align="%s" class="align-%s">' % (align, align))
-        self.context.append('</div>\n')
-    else:
-        self.body.append('<div>')
-        self.context.append('</div>\n')
+    # align
+    align = node['options'].get('align', 'default')
+    self.body.append('<div class="align-%s">' % align)
+    self.context.append('</div>\n')
 
     # reftarget
     for node_id in node['ids']:
@@ -162,16 +149,13 @@ def html_render_png(self, node):
         image.save()
 
     # align
-    if 'align' in node['options']:
-        align = node['options']['align']
-        self.body.append('<div align="%s" class="align-%s">' % (align, align))
-        self.context.append('</div>\n')
-    else:
-        self.body.append('<div>')
-        self.context.append('</div>')
+    align = node['options'].get('align', 'default')
+    self.body.append('<div class="align-%s">' % align)
+    self.context.append('</div>\n')
 
     # link to original image
     relpath = node.get_relpath('PNG', self.builder)
+    relpath = relpath.replace(os.path.sep, '/')
     if 'width' in node['options'] or 'height' in node['options'] or 'scale' in node['options']:
         self.body.append('<a class="reference internal image-reference" href="%s">' % relpath)
         self.context.append('</a>')
@@ -212,13 +196,13 @@ def html_visit_blockdiag(self, node):
 
         msg = ("blockdiag error: UnicodeEncodeError caught "
                "(check your font settings)")
-        self.builder.warn(msg)
+        logger.warning(msg)
         raise nodes.SkipNode
     except Exception as exc:
         if self.builder.config.blockdiag_debug:
             traceback.print_exc()
 
-        self.builder.warn('dot code %r: %s' % (node['code'], str(exc)))
+        logger.warning('dot code %r: %s', node['code'], exc)
         raise nodes.SkipNode
 
 
@@ -253,7 +237,7 @@ def get_image_format_for(builder):
 def on_builder_inited(self):
     # show deprecated message
     if self.builder.config.blockdiag_tex_image_format:
-        self.builder.warn('blockdiag_tex_image_format is deprecated. Use blockdiag_latex_image_format.')
+        logger.warning('blockdiag_tex_image_format is deprecated. Use blockdiag_latex_image_format.')
 
     # initialize fontmap
     global fontmap
@@ -261,19 +245,19 @@ def on_builder_inited(self):
     try:
         fontmappath = self.builder.config.blockdiag_fontmap
         fontmap = FontMap(fontmappath)
-    except:
+    except Exception:
         fontmap = FontMap(None)
 
     try:
         fontpath = self.builder.config.blockdiag_fontpath
-        if isinstance(fontpath, string_types):
+        if isinstance(fontpath, str):
             fontpath = [fontpath]
 
         if fontpath:
             config = namedtuple('Config', 'font')(fontpath)
             fontpath = detectfont(config)
             fontmap.set_default_font(fontpath)
-    except:
+    except Exception:
         pass
 
 
@@ -287,7 +271,7 @@ def on_doctree_resolved(self, doctree, docname):
         if self.builder.config.blockdiag_debug:
             traceback.print_exc()
 
-        self.builder.warn('blockdiag error: %s' % exc)
+        logger.warning('blockdiag error: %s', exc)
         for node in doctree.traverse(blockdiag_node):
             node.parent.remove(node)
 
@@ -308,7 +292,7 @@ def on_doctree_resolved(self, doctree, docname):
             if self.builder.config.blockdiag_debug:
                 traceback.print_exc()
 
-            self.builder.warn('dot code %r: %s' % (node['code'], str(exc)))
+            logger.warning('dot code %r: %s', node['code'], exc)
             node.parent.remove(node)
 
 
